///////////////////////////////////////////////////////////////////////////////
// OwnLob.java -- example how to use LOBs with self implemented LOB-interfaces
// See the example files ByteArrayBlob.java / StringClob.java

package samples;

import java.sql.*;
import java.io.*;
import java.util.*;

public class OwnLob
{   
    Connection con = null;
    
    public static void main( String args[] )
    {
        new OwnLob();   
    }
    
    OwnLob()
    {
        try {
            byte [] blobData = new byte[50];
            String clobData = "some test data ...";
            
            Arrays.fill( blobData, (byte)65 );
            
            // set logging and timeout
            DriverManager.setLogStream( System.out );
            DriverManager.setLoginTimeout( 10 );

            // loading the driver
            new com.inet.ora.OraDriver();      
              
            // get the connection
            con = DriverManager.getConnection( "jdbc:inetora:host:1521:service", "system", "manager" );
            
            // creating a test table
            try {
                con.createStatement().execute( "drop table lobtest" );
            }
            catch( Throwable e ) {
            }
            con.createStatement().execute( "create table lobtest( cblob blob, cclob clob)" );
            
            // creating the lob objects
            Blob myBlob = new ByteArrayBlob( blobData );
            Clob myClob = new StringClob( clobData );
            
            // prepare a statement and setting the lob objects
            PreparedStatement ps = con.prepareStatement( "insert into lobtest( cblob, cclob ) values( ?, ? )" );
            ps.setBlob( 1, myBlob );
            ps.setClob( 2, myClob );
            ps.executeUpdate();
            
            // select what we have written
            ResultSet rs = con.createStatement().executeQuery( "select cblob, cclob from lobtest" );
            
            // printing the results
            if( rs.next() ) {
                InputStream in1 = rs.getBlob(1).getBinaryStream();
                InputStream in2 = rs.getClob(2).getAsciiStream();
                
                byte [] b = new byte[in1.available()];
                in1.read( b );
                System.out.println( ">" + new String( b ) + "<" );
                
                b = new byte[in2.available()];
                in2.read( b );
                System.out.println( ">" + new String( b ) + "<" );
            }
            
            // close the connection
            con.close();
        }
        catch( Throwable e ) {
            e.printStackTrace();
        }
    }
}
