/*
i-net software provides programming examples for illustration only, without warranty 
either expressed or implied, including, but not limited to, the implied warranties 
of merchantability and/or fitness for a particular purpose. This programming example 
assumes that you are familiar with the programming language being demonstrated and 
the tools used to create and debug procedures. i-net software support professionals 
can help explain the functionality of a particular procedure, but they will not modify 
these examples to provide added functionality or construct procedures to meet your 
specific needs.
 i-net software 2001


  This sample demonstrates the use of the PoolManager. The PoolManager is an 
  example of a pool manager. The PoolManager is part of i-net SEROPTO. The API
  of a pool manager is not part of the JDBC specification.
  
  The main method creates a ConnectionPoolDataSource and saves it for later use.
  The next step produces multiple threads to simulate multiple clients.

*/

package samples;

import java.sql.*;
import javax.sql.*;
import com.inet.pool.PoolManager;

public class WithPoolManager extends Thread
{
    static DataSource ds;

    public static void main(String[] argv){
        try{
            // init the PoolManager with your default values
            PoolManager manager = PoolManager.getDefault();
            manager.setMaxConnectionCount(5);
            
            // create a ConnectionPoolDataSource for the PoolManager
            // and save it in a global variable for later use
            com.inet.ora.PDataSource pds = new com.inet.ora.PDataSource();
            pds.setServerName( "localHost" );
            pds.setServiceName( "xxx" );
            pds.setPort( "1521" );
            pds.setUser( "scott" );
            pds.setPassword( "tiger" );
            pds.setLoginTimeout( 10 );
            pds.setDescription( "A Test Data Source" );
            ds = pds;
            
            
            // start multiple threads to simulate clients that use the PoolManager
            for(int i=1; i<=50; i++){
                try{
                    Thread.sleep(20);
                    (new WithPoolManager(i)).start();
                }catch(Throwable e){}
            }
            Thread.sleep(5000);
        }catch(Throwable e){
            e.printStackTrace();
        }
    }
    
    public WithPoolManager(int i){
        id = i;
    }
    
    // this method simulates a client
    public void run()
    {
        java.sql.Connection con = null;
        String query = "SELECT * FROM users";

        try
        {
            PoolManager pm = PoolManager.getDefault();
            
            con = pm.getConnection( ds );
            println("Pool Count: " + pm.getConnectionCount()+ " Free: " + pm.getFreeConnectionCount() + " Used: " + pm.getUsedConnectionCount() );
            java.sql.Statement stmt = con.createStatement();
            println(id + " Executing: " + query );
            java.sql.ResultSet rs = stmt.executeQuery (query);
            //printResultSet(rs);
            con.close();
            con = null;
        }
        catch (Throwable e)
        {
            println(id + " client got a SQLException.");
            e.printStackTrace();
        }

        println(id+" Client done!");
    }// end run

    // print to PrintStream
    void println(String msg){
        System.out.println(msg);
    }

    // print the Resultset to the PrintStream (by default the console)
    void printResultSet (ResultSet rs) throws SQLException
    {
        int i;

        ResultSetMetaData rsmd = rs.getMetaData ();

        int count = rsmd.getColumnCount ();
        StringBuffer buffer = new StringBuffer();
        for (i=1; i<=count; i++) 
        {
            if (i > 1) buffer.append("\t\t");
            buffer.append(rsmd.getColumnName(i));
        }
        println( buffer.toString() );

        while (rs.next ()) 
        {
            buffer = new StringBuffer();
            for (i=1; i<=count; i++) 
            {
                if (i > 1) buffer.append("\t\t");

                String obj = rs.getString(i);
                buffer.append( String.valueOf(obj) );
            }
            println( buffer.toString() );
        }
    }

    int id;
}